@@ -254,11 +254,11 @@ use Role::Tiny::With;
 with 'TableDataRole::Business::ID::BPOM::NutritionLabelRef';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-05-14'; # DATE
+our $DATE = '2024-05-16'; # DATE
 our $DIST = 'TableData-Business-ID-BPOM-NutritionLabelRef'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
-our %STATS = ("num_rows",228,"num_columns",4); # STATS
+our %STATS = ("num_columns",4,"num_rows",228); # STATS
 
 1;
 # ABSTRACT: Nutrients
@@ -275,7 +275,7 @@ TableDataRole::Business::ID::BPOM::NutritionLabelRef - Nutrients
 
 =head1 VERSION
 
-This document describes version 0.001 of TableDataRole::Business::ID::BPOM::NutritionLabelRef (from Perl distribution TableData-Business-ID-BPOM-NutritionLabelRef), released on 2024-05-14.
+This document describes version 0.002 of TableDataRole::Business::ID::BPOM::NutritionLabelRef (from Perl distribution TableData-Business-ID-BPOM-NutritionLabelRef), released on 2024-05-16.
 
 =head1 SYNOPSIS
 
